Learn R Programming

MixAll (version 1.4.2)

ClusterCategorical-class: Definition of the ['>ClusterCategorical] class

Description

This class defines a categorical mixture model. It inherits from the ['>IClusterModel] class. A categorical mixture model is a mixture model of the form

Arguments

Slots

component

A ['>ClusterCategoricalComponent] with the probabilities of the categorical component

Details

$$ f({x}|\boldsymbol{\theta}) \\ =\sum_{k=1}^K p_k \prod_{j=1}^d \mathcal{M}(x_j;p_{jk},1) \\ \quad {x} \in \{1,\ldots,L\}^d. $$ The probabilities can be assumed equal between all variables in order to reduce the number of parameters.

Examples

Run this code
# NOT RUN {
  getSlots("ClusterCategorical")
  data(birds)
  new("ClusterCategorical", data=birds)

# }

Run the code above in your browser using DataLab