Learn R Programming

MixAll (version 1.4.2)

ClusterCategoricalComponent: Definition of the ['>ClusterCategoricalComponent] class

Description

This class defines a categorical component of a mixture model. It inherits from ['>IClusterComponent].

Arguments

Slots

plkj

Array with the probability for the jth variable in the kth cluster to be l.

nbModalities

Integer with the (maximal) number of modalities of the categorical data.

levels

list with the original levels of the variables

See Also

['>IClusterComponent] class

Examples

Run this code
# NOT RUN {
getSlots("ClusterCategoricalComponent")

# }

Run the code above in your browser using DataLab