Learn R Programming

MixAll (version 1.4.2)

ClusterDiagGaussian: Definition of the ['>ClusterDiagGaussian] class

Description

This class defines a diagonal Gaussian mixture Model.

Arguments

Slots

component

A ['>ClusterDiagGaussianComponent] with the mean and standard deviation of the diagonal mixture model.

Details

This class inherits from the ['>IClusterModel] class. A diagonal gaussian model is a mixture model of the form: $$ f({x}|\boldsymbol{\theta}) =\sum_{k=1}^K p_k \prod_{j=1}^d \phi(x_j;\mu_{jk},\sigma^2_{jk}) \quad x \in {R}^d. $$ Some constraints can be added to the variances in order to reduce the number of parameters.

See Also

['>IClusterModel] class

Examples

Run this code
# NOT RUN {
getSlots("ClusterDiagGaussian")
data(geyser)
new("ClusterDiagGaussian", data=geyser)

# }

Run the code above in your browser using DataLab