Learn R Programming

MixAll (version 1.4.2)

ClusterDiagGaussianComponent: Definition of the ['>ClusterDiagGaussianComponent] class

Description

This class defines a diagonal Gaussian component of a mixture model. It inherits from ['>IClusterComponent].

Arguments

Slots

mean

Matrix with the mean of the jth variable in the kth cluster.

sigma

Matrix with the standard deviation of the jth variable in the kth cluster.

See Also

['>IClusterComponent] class

Examples

Run this code
# NOT RUN {
getSlots("ClusterDiagGaussianComponent")

# }

Run the code above in your browser using DataLab