Learn R Programming

MixAll (version 1.4.2)

ClusterGammaComponent: Definition of the ['>ClusterGammaComponent] class

Description

This class defines a gamma component of a mixture Model. It inherits from ['>IClusterComponent].

Arguments

Slots

shape

Matrix with the shapes of the jth variable in the kth cluster.

scale

Matrix with the scales of the jth variable in the kth cluster.

See Also

['>IClusterComponent] class

Examples

Run this code
# NOT RUN {
getSlots("ClusterGammaComponent")

# }

Run the code above in your browser using DataLab