Learn R Programming

MixAll (version 1.4.2)

ClusterStrategy: Constructor of ['>ClusterStrategy] class

Description

This class encapsulate the parameters of the clustering estimation strategies.

Arguments

Details

@slot nbTry Integer defining the number of tries. Default value: 1. @slot nbShortRun Integer defining the number of short run. Recall that the strategy launch an initialization before each short run. Default value is 5. @slot initMethod A ['>ClusterInit] object defining the way to initialize the estimation method. Default value is [ClusterInit]. @slot shortAlgo A ['>ClusterAlgo] object defining the algorithm to use during the short runs of the estimation method. Default value is clusterAlgo("EM",100,1e-04). @slot longAlgo A ['>ClusterAlgo] object defining the algorithm to use during the long run of the estimation method. Default value is clusterAlgo("EM",1000,1e-07).

Examples

Run this code
# NOT RUN {
  new("ClusterStrategy")
  shortAlgo=clusterAlgo("SEM",1000)
  longAlgo =clusterAlgo("SemiSEM",200,1e-07)
  new("ClusterStrategy", shortAlgo=shortAlgo, longAlgo=longAlgo)
  getSlots("ClusterStrategy")

# }

Run the code above in your browser using DataLab