Learn R Programming

MixAll (version 1.4.2)

IClusterPredict: Interface class ['>IClusterPredict] for predicting

Description

Interface base class for predicting clusters

Arguments

Slots

nbSample

Integer with the number of samples

nbCluster

Integer with the number of cluster

pk

Vector of size K with the proportions of each mixture.

tik

Matrix of size \(n \times K\) with the posterior probability of the ith individual to belong to kth cluster.

lnFi

Vector of size n with the log-likelihood of the ith individuals.

zi

Vector of integer of size n with the attributed class label of the individuals

algo

an instance of ['>ClusterAlgoPredict]

Examples

Run this code
# NOT RUN {
  getSlots("IClusterPredict")

# }

Run the code above in your browser using DataLab