dimVector with the dimension of the kth cluster
sigma2Vector with the standard deviation in the kth cluster.
gramMatrix storing the gram matrix if its computation is needed
kernelNamestring with the name of the kernel to use. Possible values:
"Gaussian", "polynomial", "Laplace", "linear","rationalQuadratic", "Hamming".
Default is "Gaussian".
kernelParametersvector with the parameters of the kernel.
kernelComputationboolean value set as TRUE if Gram matrix is to be computed
FALSE othewise. Default is TRUE.