Learn R Programming

MixAll (version 1.4.2)

KmmMixedDataModel: Definition of the ['>KmmMixedDataModel] class

Description

This class defines a mixed data kernel mixture Model (KMM).

Arguments

Slots

lcomponent

a list of ['>KmmComponent]

Details

This class inherits from the ['>IClusterModel] class. A model for mixed data is a mixture model of the form: $$ f({{x}}_i=({{x}}_{1i}, {{x}}_{2i},\ldots {{x}}_{Li})|\theta) = \sum_{k=1}^K p_k \prod_{l=1}^L h({{x}}_{li}). $$ The density functions (or probability distribution functions) $$h(.)$$ can be any implemented kmm model on a RKHS space.

See Also

['>IClusterModel] class

Examples

Run this code
# NOT RUN {
getSlots("KmmMixedDataModel")

# }

Run the code above in your browser using DataLab