Learn R Programming

MixAll (version 1.4.2)

KmmModel: Definition of the ['>KmmModel] class

Description

This class defines a Kernel mixture Model (KMM).

Arguments

Slots

component

A ['>KmmComponent] with the dimension and standard deviation of the kernel mixture model.

Details

This class inherits from the ['>IClusterModel] virtual class. A KMM is a mixture model of the form: $$ f({x}|\boldsymbol{\theta}) =\sum_{k=1}^K p_k \prod_{j=1}^d \phi(x_j;\sigma^2_{k}) \quad x \in {R}^d. $$ Some constraints can be added to the variances in order to reduce the number of parameters.

See Also

['>IClusterModel] class

Examples

Run this code
# NOT RUN {
getSlots("KmmModel")
data(bullsEye)
new("KmmModel", data=bullsEye)

# }

Run the code above in your browser using DataLab