Learn R Programming

MixAll (version 1.2.0)

birds: Qualitative data : morphological description of birds

Description

The data set contains details on the morphology of birds (puffins). Each individual (bird) is described by 6 qualitative variables. One variable for the gender and 5 variables giving a morphological description of the birds. There is 69 puffins divided in 2 sub-classes: lherminieri (34) and subalaris (35).

Arguments

Format

A data frame with 69 observations on the following 5 variables.

Bretagnolle, V., 2007. Personal communication, source: Museum.

Details

This data set is also part of the Rmixmod package.

Examples

Run this code
  data(birds)

Run the code above in your browser using DataLab