Learn R Programming

MixAll (version 1.2.0)

car: Qualitative data : Car Evaluation

Description

Car Evaluation Database was derived from a simple hierarchical decision model originally developed for the demonstration of DEX, M. Bohanec, V. Rajkovic: Expert system for decision making.

Arguments

Format

A data frame with 1728 observations on the following 6 variables.

Creator: Marko Bohanec Donors: Marko Bohanec & Blaz Zupan http://archive.ics.uci.edu/ml/datasets/Car+Evaluation

Examples

Run this code
  data(car)

Run the code above in your browser using DataLab