powered by
In a Categorical mixture model, we can build 4 models:
The proportions can be equal or free.
The probabilities can be equal or free for all the variables.
check if a vector of Categorical mixture model name is correct.
clusterCategoricalNames(prop = "all", probabilities = "all")clusterValidCategoricalNames(names)
clusterValidCategoricalNames(names)
A character string equal to "equal", "free" or "all". Default is "all".
a vector of character
A vector of character with the model names.
The model names are summarized in the following array:
# NOT RUN { clusterCategoricalNames() clusterCategoricalNames("all", "equal") # same as c( "categorical_pk_pk", "categorical_p_pk") # }
Run the code above in your browser using DataLab