Learn R Programming

MixAll (version 1.2.0)

clusterDiagGaussianNames: Create a vector of diagonal Gaussian mixture model names.

Description

In a diagonal Gaussian mixture model, we assume that the variance matrices are diagonal in each cluster. Assumptions on the proportions and standard deviations give rise to 8 models:
  1. The proportions can be equal or free.
  2. The standard deviations can be equal or free for all the variables.
  3. The standard deviations can be equal or free for all the clusters.

check if a vector of diagonal Gaussian mixture model name is correct.

Usage

clusterDiagGaussianNames(prop = "all", sdInCluster = "all", sdBetweenCluster = "all")
clusterValidDiagGaussianNames(names)

Arguments

prop
A character string equal to "equal", "free" or "all". Default is "all".
sdInCluster
A character string equal to "equal", "free" or "all". Default is "all".
sdBetweenCluster
A character string equal to "equal", "free" or "all". Default is "all".
names
a vector of character

Value

A vector of character with the model names.

Details

The model names are summarized in the following array:
Model Name Proportions s.d. in variables
s.d. in clusters gaussian_p_sjk Equal
Free Free gaussian_p_sj
Equal Free Equal
gaussian_p_sk Equal Equal
Free gaussian_p_s Equal
Equal Equal gaussian_pk_sjk
Free Free Free
gaussian_pk_sj Free Free
Equal gaussian_pk_sk Free
Equal Free gaussian_pk_s
Free Equal Equal

Examples

Run this code
clusterDiagGaussianNames()
## same as c("gaussian_p_sk", "gaussian_pk_sk")
clusterDiagGaussianNames(prop="all", sdInCluster="equal", sdBetweenCluster= "free")

Run the code above in your browser using DataLab