Learn R Programming

MixAll (version 1.2.0)

clusterKernelNames: Create a vector of Kernel mixture model names.

Description

In a diagonal Kernel mixture model, we can assume that
  1. The proportions can be equal or free.
  2. The standard deviations can be equal or free for all the clusters.

This give rise to four models.

check if a vector of kernel mixture model name is correct.

Usage

clusterKernelNames(prop = "all", sdBetweenCluster = "all")
clusterValidKernelNames(names)

Arguments

prop
A character string equal to "equal", "free" or "all". Default is "all".
sdBetweenCluster
A character string equal to "equal", "free" or "all". Default is "all".
names
a vector of character

Value

A vector of character with the model names.

Details

The model names are summarized in the following array:
Model Name Proportions
s.d. between clusters kernelGaussian_p_sk
Equal Free
kernelGaussian_p_s Equal
Equal kernelGaussian_pk_sk
Free Free
kernelGaussian_pk_s Free
Equal Model Name

Examples

Run this code
clusterKernelNames()
## same as c("kernelGaussian_p_sk", "kernelGaussian_pk_sk")
clusterKernelNames(prop="all", sdBetweenCluster= "free")

Run the code above in your browser using DataLab