Learn R Programming

MixAll (version 1.2.0)

clusterPoissonNames: Create a vector of Poisson mixture model names.

Description

In a Poisson mixture model, we can build 4 models:
  1. The proportions can be equal or free.
  2. The means can be equal, free or proportional for all the variables.

check if a vector of Poisson mixture model name is correct.

Usage

clusterPoissonNames(prop = "all", mean = "all")
clusterValidPoissonNames(names)

Arguments

prop
A character string equal to "equal", "free" or "all". Default is "all".
mean
A character string equal to "equal", "free", "proportional or "all". Default is "all".
names
a vector of character

Value

A vector of character with the model names.

Details

The model names are summarized in the following array:
Model Name Proportions
Mean between variables poisson_p_ljk
Equal Free
poisson_p_lk Equal
Equal poisson_p_ljlk
Equal Proportional
poisson_pk_ljk Free
Free poisson_pk_lk
Free Equal

Examples

Run this code
clusterPoissonNames()
clusterPoissonNames("all", "proportional") # same as c( "poisson_pk_ljlk", "poisson_p_ljlk")

Run the code above in your browser using DataLab