Learn R Programming

MixAll (version 1.2.0)

learnAlgo: Create an instance of the [LearnAlgo] class

Description

There is two algorithms and two stopping rules possibles for a learning algorithm.
  • Algorithms:
    • Impute Impute the missing values during the iterations
    • Simul Simulate the missing values during the iterations

  • Stopping rules:
    • nbIteration Set the maximum number of iterations.
    • epsilon Set relative increase of the log-likelihood criterion.

  • Default values are $200$ nbIteration of Simul.

The epsilon value is not used when the algorithm is "Simul". It is worth noting that if there is no missing values, the method should be "Impute" and nbIteration should be set to 1!

Usage

learnAlgo(algo = "Simul", nbIteration = 200, epsilon = 1e-07)

Arguments

algo
character string with the estimation algorithm. Possible values are "Simul", "Impute". Default value is "Simul".
nbIteration
Integer defining the maximal number of iterations. Default value is 200.
epsilon
Real defining the epsilon value for the algorithm. Not used by the "Simul" algorithm. Default value is 1.e-7.

Value

a [LearnAlgo] object

Examples

Run this code
learnAlgo()
learnAlgo(algo="simul", nbIteration=50)
learnAlgo(algo="impute", epsilon = 1e-06)

Run the code above in your browser using DataLab