Learn R Programming

MixAll (version 1.2.0)

missingValues: Return the missing values of a component or a cluster class.

Description

The missing methods allow the user to get the imputed mssing values from a mixture model.

Usage

missingValues(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)
"missingValues"(x)

Arguments

x
an object that can return the imputed missing values

Value

A matrix with three columns (row index, column index, value)

Examples

Run this code
## Not run: 
# ## add 10 missing values as random
# data(geyser)
# x = as.matrix(geyser); n <- nrow(x); p <- ncol(x);
# indexes <- matrix(c(round(runif(5,1,n)), round(runif(5,1,p))), ncol=2);
# x[indexes] <- NA;
# ## estimate model (using fast strategy, results may be misleading)
# model <- clusterDiagGaussian(data=x, nbCluster=2:3, strategy = clusterFastStrategy())
# missingValues(model)
# ## End(Not run)

Run the code above in your browser using DataLab