powered by
'>ClusterDiagGaussianComponent
This class defines a diagonal Gaussian component of a mixture model. It inherits from ['>IClusterComponent].
'>IClusterComponent
mean
Matrix with the mean of the jth variable in the kth cluster.
sigma
Matrix with the standard deviation of the jth variable in the kth cluster.
['>IClusterComponent] class
# NOT RUN { getSlots("ClusterDiagGaussianComponent") # }
Run the code above in your browser using DataLab