powered by
'>ClusterGammaComponent
This class defines a gamma component of a mixture Model. It inherits from ['>IClusterComponent].
'>IClusterComponent
shape
Matrix with the shapes of the jth variable in the kth cluster.
scale
Matrix with the scales of the jth variable in the kth cluster.
['>IClusterComponent] class
# NOT RUN { getSlots("ClusterGammaComponent") # }
Run the code above in your browser using DataLab