nbSampleInteger with the number of samples
nbClusterInteger with the number of cluster
pkVector of size K with the proportions of each mixture.
tikMatrix of size \(n \times K\) with the posterior probability of
the ith individual to belong to kth cluster.
lnFiVector of size n with the log-likelihood of the ith individuals.
ziVector of integer of size n with the attributed class label of the individuals
algoan instance of ['>ClusterAlgoPredict]