Learn R Programming

MixAll (version 1.2.0)

clusterCategoricalNames: Create a vector of Categorical mixture model names.

Description

In a Categorical mixture model, we can build 4 models:
  1. The proportions can be equal or free.
  2. The probabilities can be equal or free for all the variables.

check if a vector of Categorical mixture model name is correct.

Usage

clusterCategoricalNames(prop = "all", probabilities = "all")
clusterValidCategoricalNames(names)

Arguments

prop
A character string equal to "equal", "free" or "all". Default is "all".
probabilities
A character string equal to "equal", "free" or "all". Default is "all".
names
a vector of character

Value

A vector of character with the model names.

Details

The model names are summarized in the following array:
Model Name Proportions
Probabilities between variables categorical_p_pjk
Equal Free
categorical_p_pk Equal
Equal categorical_pk_pjk
Free Free
categorical_pk_pk Free
Equal Model Name

Examples

Run this code
clusterCategoricalNames()
clusterCategoricalNames("all", "equal") # same as c( "categorical_pk_pk", "categorical_p_pk")

Run the code above in your browser using DataLab