clusterDiagGaussianNames: Create a vector of diagonal Gaussian mixture model names.
Description
In a diagonal Gaussian mixture model, we assume that the variance
matrices are diagonal in each cluster. Assumptions on the proportions
and standard deviations give rise to 8 models:
The proportions can be equal or free.
The standard deviations can be equal or free for all the variables.
The standard deviations can be equal or free for all the clusters.
check if a vector of diagonal Gaussian mixture model name is correct.
clusterDiagGaussianNames()
## same as c("gaussian_p_sk", "gaussian_pk_sk")clusterDiagGaussianNames(prop="all", sdInCluster="equal", sdBetweenCluster= "free")