ClusterStrategy] classclusterSemiSEMStrategy() create an instance of [ClusterStrategy]
for users with many missing values uning a semiSem algorithm.
clusterSEMStrategy() create an instance of [ClusterStrategy]
for users with many missing values using a SEM algorithm.
clusterFastStrategy() create an instance of [ClusterStrategy] for impatient user.
clusterStrategy(nbTry = 1, nbInit = 5, initMethod = "class", initAlgo = "EM", nbInitIteration = 20, initEpsilon = 0.01, nbShortRun = 5, shortRunAlgo = "EM", nbShortIteration = 100, shortEpsilon = 1e-04, longRunAlgo = "EM", nbLongIteration = 1000, longEpsilon = 1e-07)
clusterSemiSEMStrategy()
clusterSEMStrategy()
clusterFastStrategy()clusterInit]$
for possible values. Default is "class".clusterAlgo] for possible values. Default value: "EM".initAlgo = "EM", "CEM" or "SemiSEM". This is the number of iterations if initAlgo = "SEM".
Default value: 20.initEpsilon is not used by the SEM algorithm. Default value: 0.01.shortRunAlgo = "EM", "CEM" or "semiSEM", or the number of iterations if shortRunAlgo = "SEM".
Default value: 100.SEM algorithm. Default value: 1e-04.shortRunAlgo = "EM", "CEM" or "SemiSEM", or the number of iterations if shortRunAlgo = "SEM".
Default value: 1000.SEM algorithm. Default value: 1e-07.ClusterStrategy] object
nbShortRun short iterations of the initialization step and
of the EM, CEM, SEM or SemiSEM algorithm.
nbInit initializations using the [clusterInit]
method.
EM, CEM, SEM or SemiSEM algorithm.
For example if nbInit is 5 and nbShortRun is also 5, there will
be 5 packets of 5 models initialized. In each packet, the best model will be
ameliorated using a short run. Among the 5 models ameliorated one will be
estimated until convergence using a long run. In total there were 25 initializations.
The whole process can be repeated at least nbTry times. If a try
success, the estimated model is returned, otherwise an empty model is returned.
clusterStrategy()
clusterStrategy(longRunAlgo= "CEM", nbLongIteration=100)
clusterStrategy(nbTry = 1, nbInit= 1, shortRunAlgo= "SEM", nbShortIteration=100)
clusterSemiSEMStrategy()
clusterSEMStrategy()
clusterFastStrategy()
Run the code above in your browser using DataLab