learnAlgo: Create an instance of the [LearnAlgo] class
Description
There is two algorithms and two stopping rules possibles for a learning
algorithm.
Algorithms:
Impute Impute the missing values during the iterations
Simul Simulate the missing values during the iterations
Stopping rules:
nbIteration Set the maximum number of iterations.
epsilon Set relative increase of the log-likelihood criterion.
Default values are $200$ nbIteration of Simul.
The epsilon value is not used when the algorithm is "Simul". It is worth noting
that if there is no missing values, the method should be "Impute" and nbIteration
should be set to 1!